@@ -424,7 +424,7 @@ where
     noop_visit_mut_type!();
 
     fn visit_mut_fn_expr(&mut self, n: &mut FnExpr) {
-        if n.function.span.has_mark(self.marks.standalone) {
+        if false && n.function.span.has_mark(self.marks.standalone) {
             self.optimize_unit_repeatedly(n);
             return;
         }
@@ -433,8 +433,9 @@ where
     }
 
     fn visit_mut_module(&mut self, n: &mut Module) {
-        let is_bundle_mode = n.span.has_mark(self.marks.bundle_of_standalone);
+        let is_bundle_mode = false && n.span.has_mark(self.marks.bundle_of_standalone);
 
+        // Disable
         if is_bundle_mode {
             self.left_parallel_depth = MAX_PAR_DEPTH - 1;
         } else {
