@@ -19,7 +19,7 @@ where
         match s {
             Stmt::While(stmt) => {
                 self.changed = true;
-                log::debug!("loops: Converting a while loop to a for loop");
+                tracing::debug!("loops: Converting a while loop to a for loop");
                 *s = Stmt::For(ForStmt {
                     span: stmt.span,
                     init: None,
@@ -32,7 +32,7 @@ where
                 let val = stmt.test.as_pure_bool();
                 if let Value::Known(true) = val {
                     self.changed = true;
-                    log::debug!("loops: Converting an always-true do-while loop to a for loop");
+                    tracing::debug!("loops: Converting an always-true do-while loop to a for loop");
 
                     *s = Stmt::For(ForStmt {
                         span: stmt.span,
@@ -81,7 +81,7 @@ where
                         // will remove block and with the next pass we can apply
                         // this pass.
                         self.changed = true;
-                        log::debug!("loops: Compressing for-if-break into a for statement");
+                        tracing::debug!("loops: Compressing for-if-break into a for statement");
 
                         // We negate because this `test` is used as a condition for `break`.
                         self.negate(test, true);
